@@ -1,17 +1,9 @@
 from django.conf import settings
-from django.conf.urls.defaults import patterns, url
-from django.core.urlresolvers import get_callable
+from django.conf.urls import patterns, url
+from django.core.urlresolvers import get_callable, reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 from django.views.generic import RedirectView
 
-try:
-    from django.core.urlresolvers import reverse_lazy
-except ImportError:
-    # Support for django <1.4
-    from django.core.urlresolvers import reverse
-    from django.utils.functional import lazy
-    reverse_lazy = lazy(reverse, str)
-
 
 auth_form = get_callable(getattr(settings, 'INCUNA_AUTH_LOGIN_FORM', 'incuna_auth.forms.IncunaAuthenticationForm'))
 reset_form = get_callable(getattr(settings, 'INCUNA_PASSWORD_RESET_FORM', 'incuna_auth.forms.CrispyPasswordResetForm'))
